<?php

namespace Drupal\mercury_editor_content_moderation\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Session\AccountInterface;
use Drupal\paragraphs\ParagraphsTypeInterface;
use Drupal\layout_paragraphs\LayoutParagraphsLayout;
use Drupal\layout_paragraphs\Access\LayoutParagraphsBuilderAccess;

/**
 * Limits access to the front-end builder to only unpublished drafts.
 */
class ModerationStateAccess extends LayoutParagraphsBuilderAccess {

  /**
   * {@inheritDoc}
   */
  public function access(
    AccountInterface $account,
    LayoutParagraphsLayout $layout_paragraphs_layout,
    string $operation = NULL,
    string $component_uuid = NULL,
    ParagraphsTypeInterface $paragraph_type = NULL
  ) {
    $access = parent::access($account, $layout_paragraphs_layout, $operation, $component_uuid, $paragraph_type);
    // Only permit access to the builder if the parent entity is unpublished.
    if ($operation === NULL) {
      /** @var \Drupal\Core\Entity\EntityPublishedInterface $entity */
      $entity = $layout_paragraphs_layout->getEntity();
      $moderation_access = $entity->isPublished() ? AccessResult::forbidden() : AccessResult::allowed();
      $access = $access->andIf($moderation_access);
    }
    return $access;
  }

}
