/**
 * @file
 * Extends the Drupal dialog AJAX functionality to integrate the mercury dialog.
 */

 (function ($, Drupal) {

    /**
     * Command to open a dialog.
     *
     * @param {Drupal.Ajax} ajax
     *   The Drupal Ajax object.
     * @param {object} response
     *   Object holding the server response.
     * @param {number} [status]
     *   The HTTP status code.
     *
     * @return {bool|undefined}
     *   Returns false if there was no selector property in the response object.
     */
    Drupal.AjaxCommands.prototype.openMercuryDialog = function (ajax, response, status) {
      if (!response.selector) {
        return false;
      }
      let $dialog = $(response.selector);
      if (!$dialog.length) {
        // Create the element if needed.
        $dialog = $(
          `<mercury-dialog id="${response.selector.replace(
            /^#/,
            '',
          )}" class="ui-front"></mercury-dialog>`,
        ).appendTo('body');
      }
      // Set up the wrapper, if there isn't one.
      if (!ajax.wrapper) {
        ajax.wrapper = $dialog.attr('id');
      }

      // Use the ajax.js insert command to populate the dialog contents.
      response.command = 'insert';
      response.method = 'html';
      ajax.commands.insert(ajax, response, status);

      // Move the buttons to the jQuery UI dialog buttons area.
      if (!response.dialogOptions.buttons) {
        response.dialogOptions.drupalAutoButtons = true;
        response.dialogOptions.buttons =
          Drupal.behaviors.mercuryDialog.prepareDialogButtons($dialog);
      }

      // Bind dialogButtonsChange.
      $dialog.on('dialogButtonsChange', () => {
        const buttons = Drupal.behaviors.mercuryDialog.prepareDialogButtons($dialog);
      });

      // Open the dialog itself.
      response.dialogOptions = response.dialogOptions || {};
      const dialog = $dialog.get(0);
      Drupal.behaviors.mercuryDialog.applyOptions(dialog, response.dialogOptions);

      if (response.dialogOptions.modal) {
        dialog.showModal();
      } else {
        dialog.show();
      }
    };

    /**
     * Command to close a dialog.
     *
     * @param {Drupal.Ajax} ajax
     *   The Drupal Ajax object.
     * @param {object} response
     *   Object holding the server response.
     * @param {number} [status]
     *   The HTTP status code.
     *
     * @return {bool|undefined}
     *   Returns false if there was no selector property in the response object.
     */
    Drupal.AjaxCommands.prototype.closeMercuryDialog = function (ajax, response, status) {
      if (!response.selector) {
        return false;
      }
      let dialog = document.querySelector(response.selector);
      if (!dialog) {
        dialog = window.parent.document.querySelector(response.selector);
      }
      if (dialog) {
        Drupal.mercuryDialog(dialog).close();

        if (!response.persist) {
          dialog.remove();
        }
      }
    };

})(jQuery, Drupal);
