(($, Drupal, once) => {
  function dialogButtonsObserver(mutationList, observer) {
    for (const mutation of mutationList) {
      if (mutation.type == 'childList') {
        if (
          mutation.target.classList.contains('me-dialog__buttonpane') &&
          mutation.addedNodes.length &&
          mutation.addedNodes[0].classList.contains('button--primary')) {
          insertCancelButtonAfter(mutation.addedNodes[0]);
        }
      }
    }
  }
  function insertCancelButtonAfter(element) {
    if (!element) {
      return;
    }
    const dialog = element.closest('.me-edit-tray');
    if (dialog && element) {
      // If the cancel button already exists, remove it.
      const existing = element.parentNode.querySelector('.button--cancel');
      if (existing) {
        existing.remove();
      }
      const cancelButton = document.createElement('button');
      cancelButton.textContent = Drupal.t('Close');
      cancelButton.classList = 'button button--cancel';
      cancelButton.addEventListener('click', (event) => {
        if (confirmClose()) {
          dialog.close();
        }
      })
      element.after(cancelButton);
    }
  }
  function confirmClose() {
    if(document.querySelector('.is_changed[data-lpb-id]')) {
      return confirm(Drupal.t('You have unsaved changes. Really cancel?'));
    }
    return true;
  }

  Drupal.mercuryEditorRefreshView = function(key, reset) {
    Drupal.ajax({
      progress: {
        type: 'mercuryeditor'
      },
      url: '/mercury-editor-edit-tray/refresh-view/' + key,
      submit: { reset }
    }).execute();
  }

  Drupal.behaviors.mercuryEditorEditTray = {
    attach: function(context, settings) {
      (document.querySelectorAll('[data-me-edit-tray-key]') || []).forEach((el) => {
        const isEditing = el.querySelector('.lp-builder');
        if (isEditing) {
          el.classList.add('is-mercury-edit-mode');
        }
        else {
          el.classList.remove('is-mercury-edit-mode');
        }
      });

      once('me-edit-tray', '.me-edit-tray').forEach((dialog) => {
        // Hide the dropbtn tabs block.
        const dropBtn = document.querySelector('.me-dropbtn-block');
        if (dropBtn) {
          dropBtn.classList.add('visually-hidden');
        }
        // Add the cancel button.
        const submitButton = document.querySelector('.me-edit-tray .button--primary');
        insertCancelButtonAfter(submitButton);
        // Observe for changes to dialog buttons and re-add cancel button
        // if necessary.
        const observer = new MutationObserver(dialogButtonsObserver);
        observer.observe(dialog, {childList: true, subtree: true});
        dialog.shadowRoot.querySelector('#closeButton').addEventListener('click', (event) => {
          if (!confirmClose()) {
            event.stopPropagation();
            event.preventDefault();
            return false;
          }
        });
        dialog.addEventListener('close', () => {
          // Redirect if necessary.
          const alwaysRedirect = settings.mercuryEditorEditTray.settings.alwaysRedirect;
          const redirectSpecificCase = window.mercuryEditorEditTrayRedirectUrl && window.mercuryEditorEditTrayRedirectUrl !== window.location.href;
          if (window.mercuryEditorEditTrayRedirectUrl && (alwaysRedirect || redirectSpecificCase)) {
            window.location.href = window.mercuryEditorEditTrayRedirectUrl;
            return;
          }
          // Re-show the dropbtn tabs block.
          const dropBtn = document.querySelector('.me-dropbtn-block');
          if (dropBtn) {
            dropBtn.classList.remove('visually-hidden');
          }
          // Refresh the node view.
          [...document.querySelectorAll('[data-me-edit-tray-key]')].forEach((element) => {
            Drupal.mercuryEditorRefreshView(element.getAttribute('data-me-edit-tray-key'), true);
          });
        });
      });
      once('me-edit-tray-node-open', 'html').forEach((element) => {
        if (window.location.href.indexOf('#mercury-edit-tray') > -1) {
          const toggle = document.querySelector('.me-edit-tray-toggle');
          const dialogTitle = toggle.getAttribute('title') || Drupal.t('Edit');
          const nodeElement = document.querySelector('[data-me-edit-tray-key]');
          if (nodeElement) {
            const uuid = nodeElement.getAttribute('data-me-edit-tray-key');
            Drupal.mercuryEditorIframeOpenDialog('/mercury-editor/edit-tray/' + uuid, {
              title: dialogTitle,
              dock: 'right',
              width: '400px',
              modal: false,
              push: true,
              resizable: true,
              dialogClass: 'lpb-dialog me-edit-tray'
            });
          }
        }
      });
    }
  }
})(jQuery, Drupal, once)
