<?php

namespace Drupal\mercury_editor_edit_tray\Controller;

use Drupal\node\NodeInterface;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\Core\Ajax\AjaxHelperTrait;
use Symfony\Component\HttpFoundation\Request;
use Drupal\node\Controller\NodeViewController;

/**
 * Class MercuryEditorEditTrayController.
 *
 * Refreshes the node being edited in the tray.
 */
class MercuryEditorEditTrayController extends NodeViewController {

  use AjaxHelperTrait;

  /**
   * Returns the rendered node.
   */
  public function refresh(Request $request, $mercury_editor_edit_tray_entity) {
    $reset = $request->get('reset');
    if ($reset) {
      $type = $mercury_editor_edit_tray_entity->getEntityTypeId();
      $id = $mercury_editor_edit_tray_entity->id();
      if ($id) {
        $mercury_editor_edit_tray_entity = $this->entityTypeManager->getStorage($type)->load($id);
      }
    }
    $rendered_node = parent::view($mercury_editor_edit_tray_entity, 'full');
    if ($this->isAjax()) {
      $response = new AjaxResponse();
      $response->addCommand(new ReplaceCommand('[data-me-edit-tray-key="' . $mercury_editor_edit_tray_entity->uuid() . '"]', $rendered_node));
      return $response;
    }
    return $rendered_node;
  }

  /**
   * Returns the edit form for a entity in tempstore to be rendered in the tray.
   *
   * @param \Drupal\node\NodeInterface $mercury_editor_edit_tray_entity
   *   The node stored in the tempstore.
   *
   * @return array
   *   The build array.
   */
  public function editTray(NodeInterface $mercury_editor_edit_tray_entity) {
    $edit_form = \Drupal::entityTypeManager()->getFormObject('node', 'mercury_editor')->setEntity($mercury_editor_edit_tray_entity);
    return \Drupal::formBuilder()->getForm($edit_form);
  }

}
