<?php

namespace Drupal\mercury_editor_edit_tray\Controller;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\node\Entity\Node;
use Drupal\node\NodeTypeInterface;
use Drupal\node\Controller\NodeViewController;

class NodeCreateController extends NodeViewController {

  use StringTranslationTrait;

  public function createNode(NodeTypeInterface $node_type) {
    $mercury_edit_tray_types = \Drupal::configFactory()->get('mercury_editor_edit_tray.settings')->get('content_types');
    if (isset($mercury_edit_tray_types[$node_type->id()])) {
      $tempstore = \Drupal::service('mercury_editor_edit_tray.tempstore_repository');
      $type_id = $node_type->id();
      $title = $this->t('New @type', ['@type' => $node_type->label()]);
      $new_node = Node::create([
        'type' => $type_id,
        'uid' => $this->currentUser->id(),
        'in_preview' => TRUE,
        'preview_view_mode' => 'full',
        'field_content' => [],
        'title' => $title,
        'status' => FALSE,
      ]);
      $tempstore->set($new_node);
      $page = parent::view($new_node, 'full');
      // Always redirect after closing the edit tray from node/add.
      $page['#attached']['drupalSettings']['mercuryEditorEditTray']['settings']['alwaysRedirect'] = TRUE;
      $page['#attached']['drupalSettings']['mercuryEditorEditTray']['trayTitle'] = $title;
      $page['#attached']['library'][] = 'mercury_editor_edit_tray/node_add';
      return $page;
    }
    else {
      $values = ['type' => $node_type->id()];

      $node = $this->entityTypeManager
        ->getStorage('node')
        ->create($values);

      $form = \Drupal::entityTypeManager()
        ->getFormObject('node', 'default')
        ->setEntity($node);
      return \Drupal::formBuilder()->getForm($form);
    }
  }

}
