<?php

namespace Drupal\mercury_editor_edit_tray;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\TempStore\PrivateTempStoreFactory;

/**
 * Layout Paragraphs Layout Tempstore Repository class definition.
 */
class MercuryEditorEditTrayTempstore {

  /**
   * The shared tempstore factory.
   *
   * @var \Drupal\Core\TempStore\PrivateTempStore
   */
  protected $tempStoreFactory;

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * LayoutTempstoreRepository constructor.
   *
   * @param \Drupal\Core\TempStore\PrivateTempStoreFactory $temp_store_factory
   *   The shared tempstore factory.
   */
  public function __construct(PrivateTempStoreFactory $temp_store_factory, EntityTypeManagerInterface $entity_type_manager) {
    $this->tempStoreFactory = $temp_store_factory->get('mercury_editor_edit_tray');
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * Get a content entity from the tempstore.
   *
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   *   A content entity.
   *
   * @return  \Drupal\Core\Entity\ContentEntityInterface $entity
   *   A content entity.
   */
  public function get(ContentEntityInterface $entity) {
    $key = $this->getStorageKey($entity);
    $tempstore_entity = $this->getWithStorageKey($key);
    // Editor isn't in tempstore yet, so add it.
    if (empty($tempstore_entity)) {
      $tempstore_entity = $this->set($entity);
    }
    return $tempstore_entity;
  }

  /**
   * Get a content entity frome the tempstore using its storage key.
   *
   * @param string $key
   *   The storage key.
   *
   * @return \Drupal\Core\Entity\ContentEntityInterface
   *   The entity.
   */
  public function getWithStorageKey(string $key) {
    if ($entity = $this->tempStoreFactory->get($key)) {
      return $entity;
    }
    /** @var ContentEntityInterface $entity */
    $entities = $this->entityTypeManager->getStorage('node')->loadByProperties(['uuid' => $key]);
    if ($entities) {
      return $this->set(reset($entities));
    }
  }

  /**
   * Save a content entity to the tempstore.
   */
  public function set(ContentEntityInterface $entity) {
    $key = $this->getStorageKey($entity);
    $this->tempStoreFactory->set($key, $entity);
    return $entity;
  }

  /**
   * Delete a content entity from tempstore.
   */
  public function delete(ContentEntityInterface $entity) {
    $key = $this->getStorageKey($entity);
    $this->tempStoreFactory->delete($key);
  }

  /**
   * Returns a unique key for storing the entity.
   *
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   *   The entity.
   *
   * @return string
   *   The unique key.
   */
  public function getStorageKey(ContentEntityInterface $entity) {
    return $entity->uuid();
  }

}
