<?php

namespace Drupal\mercury_editor_edit_tray\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Menu\LocalTaskManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a "Tabs" block to display the local tasks.
 *
 * @Block(
 *   id = "mercury_editor_dropbtn_tasks_block",
 *   admin_label = @Translation("Mercury Editor Dropbutton Tabs"),
 * )
 */
class DropBtnTasksBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The local task manager.
   *
   * @var \Drupal\Core\Menu\LocalTaskManagerInterface
   */
  protected $localTaskManager;

  /**
   * The route match.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $routeMatch;

  /**
   * Creates a LocalTasksBlock instance.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Menu\LocalTaskManagerInterface $local_task_manager
   *   The local task manager.
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The route match.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, LocalTaskManagerInterface $local_task_manager, RouteMatchInterface $route_match) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->localTaskManager = $local_task_manager;
    $this->routeMatch = $route_match;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('plugin.manager.menu.local_task'),
      $container->get('current_route_match')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $tasks = $this->localTaskManager->getLocalTasks($this->routeMatch->getRouteName(), 0);
    $links = [];
    unset($tasks['tabs']['entity.node.canonical']);
    foreach ($tasks['tabs'] as $name => $tab) {
      if ($tab['#access']->isAllowed()) {
        $links[$name] = [
          '#type' => 'link',
          '#title' => $tab['#link']['title'],
          '#url' => $tab['#link']['url'],
          '#weight' => $tab['#weight'],
          '#access' => $tab['#access'],
          '#attributes' => $tab['#link']['localized_options']['attributes'] ?? [],
        ];
      }
    }
    uasort($links, '\Drupal\Component\Utility\SortArray::sortByWeightProperty');
    $cacheability = $tasks['cacheability'];
    $build = [];
    $cacheability->applyTo($build);
    if (count($links)) {
      $links[key($links)]['#attributes']['class'][] = 'me-dropbtn__btn--primary';
      $links[key($links)]['#attributes']['class'][] = 'edit-icon';
      $build = $build + [
        '#theme' => 'mercury_editor_dropbtn',
        '#items' => $links,
      ];
    }
    return $build;
  }

}
