<?php

namespace Drupal\mercury_editor_edit_tray\Routing;

use Symfony\Component\Routing\Route;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\ParamConverter\ParamConverterInterface;
use Drupal\mercury_editor_edit_tray\MercuryEditorEditTrayTempstore;

/**
 * Layout paragraphs tempstore param converter service.
 *
 * @internal
 *   Tagged services are internal.
 */
class MercuryEditorTempstoreParamConverter implements ParamConverterInterface {

  /**
   * The tempstore.
   *
   * @var \Drupal\mercury_editor_edit_tray\MercuryEditorEditTrayTempstore
   */
  protected $tempstore;

  /**
   * The Entity Type Manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new LayoutParagraphsEditorTempstoreParamConverter.
   *
   * @param \Drupal\mercury_editor_edit_tray\MercuryEditorEditTrayTempstore $tempstore
   *   The tempstore.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager service.
   */
  public function __construct(MercuryEditorEditTrayTempstore $tempstore, EntityTypeManagerInterface $entity_type_manager) {
    $this->tempstore = $tempstore;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function convert($value, $definition, $name, array $defaults) {
    if (empty($defaults['mercury_editor_edit_tray_entity'])) {
      return NULL;
    }
    $key = $defaults['mercury_editor_edit_tray_entity'];
    return $this->tempstore->getWithStorageKey($key);
  }

  /**
   * {@inheritdoc}
   */
  public function applies($definition, $name, Route $route) {
    return !empty($definition['mercury_editor_edit_tray_entity']);
  }

}
