<?php

namespace Drupal\mercury_editor_iframe\Ajax;

use Drupal\Core\Url;
use Drupal\Core\Ajax\CommandInterface;
use Drupal\layout_paragraphs\Utility\Dialog;

/**
 * Ajax command to request a single component from a layout via Ajax.
 */
class RenderComponentCommand implements CommandInterface {

  /**
   * The layout object.
   *
   * @var \Drupal\layout_paragraphs\LayoutParagraphsLayout
   */
  protected $layout;

  /**
   * The UUID of the component being inserted.
   *
   * @var string
   */
  protected $componentUuid;

  /**
   * The method to use for inserting the component.
   *
   * @var string
   */
  protected $method;

  /**
   * The css selector of the DOM element being targeted.
   *
   * @var string
   */
  protected $selector;

  /**
   * Constructor.
   */
  public function __construct($layout, $component_uuid, $method, $selector) {
    $this->layout = $layout;
    $this->componentUuid = $component_uuid;
    $this->method = $method;
    $this->selector = $selector;
  }

  /**
   * Render custom ajax command.
   *
   * @return array
   *   The command array.
   */
  public function render() {

    $params = [
      'layout_paragraphs_layout' => $this->layout->id(),
      'component_uuid' => $this->componentUuid,
      'method' => $this->method,
      'selector' => $this->selector,
    ];
    $url = Url::fromRoute('mercury_editor_iframe.render_component', $params)->toString();
    $dialogId = Dialog::dialogSelector($this->layout);
    return [
      'command' => 'mercuryEditorIframeRefreshLayout',
      'url' => $url,
      'dialogId' => $dialogId,
    ];

  }

}
