<?php

namespace Drupal\mercury_editor_iframe\Controller;

use Drupal\Core\Ajax\AfterCommand;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\AppendCommand;
use Drupal\Core\Ajax\BeforeCommand;
use Drupal\Core\Ajax\PrependCommand;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\Core\Ajax\AjaxHelperTrait;
use Drupal\Core\Controller\ControllerBase;
use Drupal\layout_paragraphs\LayoutParagraphsLayout;
use Drupal\layout_paragraphs\Ajax\LayoutParagraphsEventCommand;

/**
 * Updates a layout by inserting a component or refreshing the entire layout.
 */
class UpdateLayoutController extends ControllerBase {

  use AjaxHelperTrait;

  /**
   * Returns an Ajax response with rendered layout component.
   *
   * @param string $component_uuid
   *   The component uuid.
   * @param \Drupal\layout_paragraphs\LayoutParagraphsLayout $layout_paragraphs_layout
   *   The Layout Paragraphs Layout object.
   * @param string $method
   *   The jQuery method (replaceWith, before, etc.) to use for the insertion.
   * @param string $selector
   *   The DOM selector to target the jQuery operation.
   */
  public function component(string $component_uuid, LayoutParagraphsLayout $layout_paragraphs_layout, string $method, string $selector) {
    // If invoked via ajax, no need to re-render the builder UI.
    $rendered_component = [
      '#type' => 'layout_paragraphs_builder',
      '#layout_paragraphs_layout' => $layout_paragraphs_layout,
      '#uuid' => $component_uuid,
    ];
    if ($this->isAjax()) {
      $response = new AjaxResponse();
      switch ($method) {
        case 'replaceWith':
          $response->addCommand(new ReplaceCommand($selector, $rendered_component));
          break;

        case 'before':
          $response->addCommand(new BeforeCommand($selector, $rendered_component));
          break;

        case 'after':
          $response->addCommand(new AfterCommand($selector, $rendered_component));
          break;

        case 'prepend':
          $response->addCommand(new PrependCommand($selector, $rendered_component));
          break;

        case 'append':
          $response->addCommand(new AppendCommand($selector, $rendered_component));
          break;
      }
      $response->addCommand(new LayoutParagraphsEventCommand($layout_paragraphs_layout, $component_uuid, 'component:update'));
      return $response;
    }
    else {
      return $rendered_component;
    }
  }

  /**
   * Returns an Ajax response with the rendered layout.
   *
   * @param \Drupal\layout_paragraphs\LayoutParagraphsLayout $layout_paragraphs_layout
   *   The Layout Paragraphs Layout object.
   */
  public function layout(LayoutParagraphsLayout $layout_paragraphs_layout) {
    $rendered_layout = [
      '#type' => 'layout_paragraphs_builder',
      '#layout_paragraphs_layout' => $layout_paragraphs_layout,
    ];
    if ($this->isAjax()) {
      $response = new AjaxResponse();
      $response->addCommand(new ReplaceCommand('[data-lpb-id="' . $layout_paragraphs_layout->id() . '"]', $rendered_layout));
      return $response;
    }
    else {
      return $rendered_layout;
    }
  }

}
